netapp_ontap.models.node_ha_ports API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_ha_ports`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeHaPortsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeHaPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `number GET`

    HA port number

    Example: 0

  `state GET`

    HA port state:

    - down - Logical HA link is down.
    - initialized - Logical HA link is initialized. The physical link is up, but the subnet manager hasn’t started to configure the port.
    - armed - Logical HA link is armed. The physical link is up and the subnet manager started but did not yet complete configuring the port.
    - active - Logical HA link is active.
    - reserved - Logical HA link is active, but the physical link is down.

    Valid choices:

    - down
    - initialized
    - armed
    - active
    - reserved